﻿Imports System.Text
Imports System.IO
Imports System.Drawing.Imaging

Public Class Helper

    Public Shared Function CreateRandomData(dt As DataTable, RowCount As Integer) As DataTable

        dt.Clear()

        Dim rnd As New Random

        For i = 1 To RowCount

            Dim row = dt.NewRow

            For Each DataColumn As DataColumn In dt.Columns

                If Not DataColumn.AutoIncrement Then

                    Dim value As Object = Nothing
                    Try

                        Select Case True
                            Case DataColumn.DataType Is GetType(Boolean), DataColumn Is GetType(CheckState)
                                value = RandomBoolean(rnd)

                            Case DataColumn.DataType Is GetType(DateTime)
                                value = RandomDateTime(rnd, New Date(1900, 1, 1), Date.Today)

                            Case DataColumn.DataType Is GetType(Char)
                                value = RandomString(rnd, 1)

                            Case DataColumn.DataType Is GetType(String)
                                value = RandomString(rnd, CInt(RandomDecimal(rnd, 5, 25, 0)))

                            Case DataColumn.DataType Is GetType(TimeSpan)
                                value = RandomDateTime(rnd, New Date(1900, 1, 1), Date.Today) - RandomDateTime(rnd, New Date(1900, 1, 1), Date.Today)

                            Case DataColumn.DataType Is GetType(Decimal)
                                value = rnd.NextDouble * 100000 * If(RandomBoolean(rnd), -1, 1)

                            Case DataColumn.DataType Is GetType(Double)
                                value = rnd.NextDouble() * 100000

                            Case DataColumn.DataType Is GetType(Single)
                                value = RandomDecimal(rnd, -100000, 100000, 0)

                            Case DataColumn.DataType Is GetType(Byte)
                                value = RandomDecimal(rnd, Byte.MinValue, Byte.MaxValue, 0)

                            Case DataColumn.DataType Is GetType(Guid)
                                value = DBNull.Value

                            Case DataColumn.DataType Is GetType(Int16)
                                value = RandomDecimal(rnd, Int16.MinValue, Int16.MaxValue, 0)

                            Case DataColumn.DataType Is GetType(Int32)
                                value = RandomDecimal(rnd, Int32.MinValue, Int32.MaxValue, 0)

                            Case DataColumn.DataType Is GetType(Int64)
                                value = RandomDecimal(rnd, Int64.MinValue, Int64.MaxValue, 0)

                            Case DataColumn.DataType Is GetType(SByte)
                                value = RandomDecimal(rnd, SByte.MinValue, SByte.MaxValue, 0)

                            Case DataColumn.DataType Is GetType(UInt16)
                                value = RandomDecimal(rnd, UInt16.MinValue, UInt16.MaxValue, 0)

                            Case DataColumn.DataType Is GetType(UInt32)
                                value = RandomDecimal(rnd, UInt32.MinValue, UInt32.MaxValue, 0)

                            Case DataColumn.DataType Is GetType(UInt64)
                                value = RandomDecimal(rnd, UInt64.MinValue, UInt64.MaxValue, 0)

                            Case DataColumn.DataType Is GetType(Byte())
                                value = ConvertImageToByteArray(My.Resources.wichtig, ImageFormat.Png)

                        End Select
                        row(DataColumn.ColumnName) = value
                    Catch ex As Exception
                        Stop
                    End Try

                End If
            Next
            dt.Rows.Add(row)
        Next
        Return dt
    End Function

    Private Shared Function ConvertImageToByteArray(imageToConvert As System.Drawing.Image, formatOfImage As ImageFormat) As Byte()
        Dim Ret As Byte()
        Try
            Using ms As New MemoryStream()
                imageToConvert.Save(ms, formatOfImage)
                Ret = ms.ToArray()
            End Using
        Catch generatedExceptionName As Exception
            Throw
        End Try

        Return Ret
    End Function

    Public Shared Function RandomDecimal(_rnd As Random, _start As Decimal, _end As Decimal, _precision As Int32) As Decimal
        Return CDec(Math.Round((_rnd.NextDouble() * Math.Abs(_end - _start)) + _start, _precision, MidpointRounding.AwayFromZero))
    End Function

    Public Shared Function RandomDateTime(_rnd As Random, _MinDate As DateTime, _MaxDate As DateTime) As DateTime
        Dim m_Days As Integer = (_MaxDate - _MinDate).Days
        Dim m_RandomDays As Integer = _rnd.Next(0, m_Days)
        Return _MinDate.AddDays(m_RandomDays)
    End Function

    Public Shared Function RandomString(_rnd As Random, _NumberOfChars As Integer) As String
        Dim m_sb As New StringBuilder
        Dim m_Chars As Char() = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ".ToCharArray()
        For i As Integer = 0 To _NumberOfChars - 1
            m_sb.Append(m_Chars(_rnd.Next(0, m_Chars.Length - 1)).ToString())
        Next
        Return m_sb.ToString
    End Function

    Public Shared Function RandomBoolean(_rnd As Random) As Boolean
        Return (_rnd.Next(0, 2) > 0)
    End Function

End Class
